<?php
// $Id: unitrack.admin.inc,v 1.1.2.1 2010/10/05 10:57:19 valthebald Exp $

/**
 * @file
 * Provides the administration page for Unitrack.
 */
  
/**
 * Administration page for UniTrack.
 */
function unitrack_settings_page() {
  return drupal_get_form('unitrack_accounts_overview_form').drupal_get_form('unitrack_tracking_events_form');
}

function unitrack_accounts_overview_form() {
  $accounts = unitrack_get_accounts_list();
  
  foreach ($accounts as $id => $types) {
    $form[$id] = array('#type' => 'row');
  	$form[$id]['type'] = array('#value' => $types['type']);
  	$form[$id]['name'] = array('#value' => $types['name']);
  	$form[$id]['configure'] = array('#value' => l(t('Configure'), 'admin/settings/unitrack/account_conf/'. $id));
  	$form[$id]["enabled_{$id}"] = array('#type' => 'checkbox', '#default_value' => $types['enabled']);
  }
  $form['submit'] = array('#type' => 'submit', '#value' => t('Enable selected accounts'));
  
  return $form;
}

function unitrack_accounts_overview_form_submit($form, &$form_state) {
  $accounts_list = unitrack_get_accounts_list();
  
  foreach ($accounts_list as $account_id => $account) {
    if($form_state['values']["enabled_{$account_id}"]) {
      db_query('UPDATE {unitrack_types} SET enabled = 1 WHERE id = %d', $account_id);
    } else {
      db_query('UPDATE {unitrack_types} SET enabled = 0 WHERE id = %d', $account_id);
    }
  }
}

function unitrack_tracking_events_form() {
  $events = unitrack_get_events_list();
  $accounts_list = unitrack_get_accounts_list();
  
  $enabled_events = array();
  $result = db_query('SELECT * FROM {unitrack_events}');
  
  while ($enabled_event = db_fetch_object($result)) {
    $enabled_events[$enabled_event->event_id][$enabled_event->type_id] = 1;
  }
  
  foreach ($events as $event_id => $event_name) {
    $form[$event_id] = array('#type' => 'row');
    $form[$event_id]["event_name_{$event_id}"] = array('#value' => $event_name['name']);
    $form[$event_id]['configure'] = array('#value' => l(t('Configure'), 'admin/settings/unitrack/event_conf/'. $event_id));
      
    foreach ($accounts_list as $account_id => $account) {
      $form[$event_id]["cb_{$event_id}_{$account_id}"] = array('#type' => 'checkbox', '#default_value' => isset($enabled_events[$event_id][$account_id]) ? 1 : 0);
    }
  }
  
  $form['submit'] = array('#type' => 'submit', '#value' => t('Enable selected events'));
   
  return $form;
}

function unitrack_tracking_events_form_submit($form, &$form_state) {

  $events = unitrack_get_events_list();
  $accounts_list = unitrack_get_accounts_list();
  
  db_query('DELETE FROM {unitrack_events}');
  
  foreach ($events as $event_id => $event_name) {
    foreach ($accounts_list as $account_id => $account) {
      if($form_state['values']["cb_{$event_id}_{$account_id}"]) {
        db_query('INSERT INTO {unitrack_events} (event_id, type_id) VALUES (%d, %d)', $event_id, $account_id);
      }
    }
  }
}

function unitrack_get_events_list() {
  $events_list = array();
  
  $query = 'SELECT * FROM {unitrack_events_name}';
  $result = db_query($query);
  
  while ($event = db_fetch_object($result)) {
    $events_list[$event->id] = array('name' => $event->name);
  }
  
  return $events_list;
}

function theme_unitrack_accounts_overview_form($form) {
  $rows = array();
  foreach ($form as $id => $element) {
    if (isset($element['#type']) && $element['#type'] == 'row') {
      $rows[] = array(
        drupal_render($element["enabled_{$id}"]),
        drupal_render($element['type']),
        drupal_render($element['name']),
        drupal_render($element['configure']),
      );
      unset($form[$id]);
    }
  }
  $header = array(t('Enabled'), t('Type'), t('Name'), t('Operations'));
  $output = theme('table', $header, $rows);
  $output .= drupal_render($form);

  return $output;
}

function theme_unitrack_tracking_events_form($form) {
  $accounts_list = unitrack_get_accounts_list();
  $header = array(t('Events'));
  $rows = array();
  
  foreach ($accounts_list as $id => $accounts) {
  	$header[] = $accounts['name'];
  }
  
  $header[] = (t('Operations'));
  
  foreach ($form as $id => $element) {
    if (isset($element['#type']) && $element['#type'] == 'row') {
      $row = array($element["event_name_$id"]['#value']);
      foreach ($accounts_list as $account_id => $account) {
        $row[] = drupal_render($element["cb_{$id}_{$account_id}"]);
      }
      $row[] = (drupal_render($element['configure']));
      $rows[] = $row;      
      
      unset($form[$id]);
    }
  }
  
  $output = theme('table', $header, $rows);
  $output .= drupal_render($form);
  
  return $output;
}

function unitrack_get_account_name($account_id) {
  $accounts_list = unitrack_get_accounts_list();
  return $accounts_list[$account_id]['name'];
}

function unitrack_accounts_configuration($account_id) {
  switch ($account_id) {
  	case 1:
      return drupal_get_form('unitrack_ga_settings_form');
  	case 2:
      return drupal_get_form('unitrack_getclicky_settings_form');
  }
}


function unitrack_getclicky_settings_form() {

  $form['#redirect'] = 'admin/settings/unitrack';
  $form['unitrack_getclicky_site_id_number'] = array(
    '#type' => 'textfield',
    '#title' => t('Site ID Number'),
    '#default_value' => variable_get('unitrack_getclicky_site_id_number', ''),
    '#size' => 15,
    '#maxlength' => 20,
    '#required' => TRUE,
    '#description' => t('Example input: 130169<br>
    This number is unique to every website you track via Clicky(a.k.a. GetClicky).<br>
    - If you <b>do not</b> have an account with Clicky - you can obtain one from the <a href="@url1">GetClicky</a> website. (clicking on this link shows your support for my development of this module - especially if you decide to buy a Pro account with Clicky. Here is <a href="http://getclicky.com/#theotherguys">why</a> and here is <a href="http://getclicky.com/help/pricing">accounts comparison</a>)<br>
    - If you <b>DO</b> have a Clicky account - you can find that number here:<br>
      - anywhere you see a link like that <a href="@url2">http://getclicky.com/<b>130169</b></a> - take only the number - this is your Clicky site ID number.
      - you can find this in your affiliate link (if you have many sites tracked by one Clicky user account - the affiliate link uses the 1st site\'s ID), <br>
      - also in your tracking code and in your site prefs page ...
    
    ', 
    array('@url1' => 'http://getclicky.com/130169', '@url2' => 'http://getclicky.com/130169')  ),
    );

  $form['unitrack_getclicky_site_key_number'] = array(
    '#type' => 'textfield',
    '#title' => t('Site Key Number'),
    '#default_value' => variable_get('unitrack_getclicky_site_key_number', ''),
    '#size' => 100,
    '#maxlength' => 100,
    '#required' => FALSE,
    '#description' => t('Example input: 72543da7406597242<br>
    This number is an API key used to display stats on the <a hre"">page</a>.'),
    );
   
  $form['submit'] = array(
    '#type' => 'submit', 
    '#value' => t('Save settings'),
  );
  
  return $form;
}

function unitrack_getclicky_settings_form_submit($form, &$form_state) {
  variable_set('unitrack_getclicky_site_id_number', $form_state['values']['unitrack_getclicky_site_id_number']);
  variable_set('unitrack_getclicky_site_key_number', $form_state['values']['unitrack_getclicky_site_key_number']); 
}

function unitrack_ga_settings_form() {
  
   $form['#redirect'] = 'admin/settings/unitrack';
   
    $form['unitrack_googleanalytics_account'] = array(
    '#type' => 'textfield',
    '#title' => t('Google Analytics account number'),
    '#default_value' => variable_get('unitrack_googleanalytics_account', 'UA-'),
    '#size' => 15,
    '#maxlength' => 20,
    '#required' => TRUE,
    '#description' => t('The account number is unique to the websites domain. Click the <strong>Edit</strong> link in your Google Analytics account next to the appropriate profile on the <strong>Analytics Settings</strong> page, then select <strong>Check Status</strong> at the top-right of the table to find the account number (UA-xxxx-x) of your site. You can obtain a user account from the <a href="@url">Google Analytics</a> website.', array('@url' => 'http://www.google.com/analytics/')),
  ); 

  $form['submit'] = array(
    '#type' => 'submit', 
    '#value' => t('Save settings'),
  );
  
  return $form;
}

function unitrack_ga_settings_form_submit($form, &$form_state) {
  variable_set('unitrack_googleanalytics_account', $form_state['values']['unitrack_googleanalytics_account']);
}
